@@ -216,7 +216,7 @@ class Ghettovcb(Archiver):
             if not (0<self.port and self.port<65535):
                 errors['port']='must be an integer between 1 and 65535'
 
-        for name in ('login', 'password', 'local', 'remote_temp',):
+        for name in ('login', 'password', 'local'):
             value=job.get(name, None)
             if not value:
                 errors[name]='option mandatory'
@@ -225,6 +225,8 @@ class Ghettovcb(Archiver):
                 if name=='password':
                     self.register_password(value)
 
+        self.remote_temp=job.get('remote_temp', '/tmp')
+
         try:
             self.vm_list=quoted_string_list(job.get('vm_list', ''))
         except ValueError:
@@ -293,8 +295,6 @@ class Ghettovcb(Archiver):
             
         self.destination=job.get('destination', None)
         if self.destination:
-            if not self.vm_list:
-                 errors['destination']='vm_list must be set to use "destination"'
                  
             self.destination=self.destination.replace('\n','')
             try:
