@@ -74,11 +74,12 @@ def update_check(version, backend):
     """
     
     up2date, msg='yes', ''
-    data=urllib.urlencode(dict(version=version, backend=backend))
+    data=urllib.urlencode(dict(version=version, backend=backend, platform=sys.platform, osver=platform.version()[:10]))
     current=__version__.split('.')
 
     try:
-        data=urllib2.urlopen(last_version_url, data).read()
+        data=urllib2.urlopen('%s?%s' % (last_version_url, data)).read()
+#        data=urllib2.urlopen(last_version_url, data).read()
         state='version'
         msg=''
         vall=vbackend=None
@@ -122,21 +123,27 @@ def update_check(version, backend):
 
     return up2date, msg
 
+# ---------------------------------------------------------------------------        
+def gen_status(start, job, status, end):
+
+    if end==None:
+        end=int(time.time())
+    st=u''
+    st+='name=%s\r\n' % job['name']
+    st+='program=%s\r\n' % job.get('program','')
+    st+='version=%s\r\n' % __version__
+    st+='status=%s\r\n' % (status, )
+    st+='hostname=%s\r\n' % platform.node()
+    st+='start=%s\r\n' % time.ctime(start)
+    st+='end=%s\r\n' % time.ctime(end)
+    st+='start_epoch=%d\r\n' % start
+    st+='end_epoch=%d\r\n' % end
+    return st
+
 # ---------------------------------------------------------------------------        
 def mail_exception(start, job, extra, manager, subject):
     
-    end=int(time.time())
-
-    status=u''
-    status+='name=%s\r\n' % job['name']
-    status+='program=%s\r\n' % job.get('program','')
-    status+='version=%s\r\n' % __version__
-    status+='status=ERR\r\n'
-    status+='hostname=%s\r\n' % platform.node()
-    status+='start=%s\r\n' % time.ctime(start)
-    status+='end=%s\r\n' % time.ctime(end)
-    status+='start_epoch=%d\r\n' % start
-    status+='end_epoch=%d\r\n' % end
+    status=gen_status(start, job, 'ERR', None)
     status+='runtime_error=%r\r\n' % sys.exc_info()[1]
     
     msg_body=job['msg_header']
@@ -155,9 +162,16 @@ def mail_exception(start, job, extra, manager, subject):
     
     attachments=manager.attachments[:]
     attachments+=[ # the type, subtype and coding is not used
-           ('traceback.txt', None, tb_st.decode('ascii', 'replace'), 'text', 'plain', 'utf-8'), # ascii is already utf8
+           ('traceback.txt', None, tb_st.decode('ascii', 'replace'), 'text', 'plain', 'utf-8'), # ascii is already utf8, no need to encode
            ('status.txt', None, status.encode('utf-8'), 'text', 'plain', 'utf-8'),
     ]
+
+    try:
+        log_output=manager.stop_logging()
+        attachments.append(('logging.txt', None, log_output.encode('utf-8'), 'text', 'plain', 'utf-8'))
+    except Exception:
+        msg_body+='\nminor error when attaching logging\n'                      
+    
     errmsg=sendmail(job, subject, msg_body, attachments, manager.log)
 
 
@@ -432,7 +446,10 @@ def main():
                     
             if job['mail'] and not mail_config_errors and not command=='check':
                 subject='MKSBACKUP %s ERR %s ' % (command_display, job['name'], )
-                errmsg=sendmail(job, subject, msg_body, manager.attachments, manager.log)
+                status=gen_status(start, job, 'ERR', None)
+                attachments=manager.attachments[:]
+                attachments.append(('status.txt', None, status.encode('utf-8'), 'text', 'plain', 'utf-8')),
+                errmsg=sendmail(job, subject, msg_body, attachments, manager.log)
     
             continue
     
